@@ -389,15 +389,36 @@ def ==(other)
     end
 end
 
-def === (other)
-    reduce5.ptree.deref.to_s == other.ptree.deref.to_s
-end
+#def === (other)
+#    reduce5.ptree.deref.to_s == other.reduce5.ptree.deref.to_s
+#end
+
+alias === ==
+
+#def === (other)
+#  # returns true if other is within a factor and/or offset of difference.
+#  case other
+#  when self.class
+#    (self/other).reduce5.ptree.children.each do |child|
+#      return false if !( NumberNode === child )
+#    end
+#    true
+#  else
+#    false
+#  end
+#end
+
 
 def =~(other)
+  case other
+  when self.class
     (self/other).reduce5.ptree.children.each{ |node|
-       return false unless NumberNode === node
+      return false unless NumberNode === node
     }
     true
+  else
+    false
+  end
 end
 
 def self::pow_f(a, b)
